summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/game-server/being.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/game-server/being.cpp b/src/game-server/being.cpp
index 8b4c2967..1d8ff094 100644
--- a/src/game-server/being.cpp
+++ b/src/game-server/being.cpp
@@ -193,8 +193,8 @@ void BeingComponent::move(Entity &entity)
// zone to another.
mOld = entity.getComponent<ActorComponent>()->getPosition();
- // Ignore not moving beings
- if (mAction == STAND && mDst == mOld)
+ // Ignore not moving or dead beings
+ if ((mAction == STAND && mDst == mOld) || mAction == DEAD)
return;
if (mMoveTime > WORLD_TICK_MS)